@@ -7,12 +7,14 @@ A generic class for creating Elements.
 """
 
 import base64
+from html import escape
 import json
 import warnings
 from collections import OrderedDict
-import urllib.parse
 from urllib.request import urlopen
-from uuid import uuid4
+from binascii import hexlify
+from os import urandom
+from pathlib import Path
 
 from jinja2 import Environment, PackageLoader, Template
 
@@ -50,7 +52,7 @@ class Element(object):
 
     def __init__(self, template=None, template_name=None):
         self._name = 'Element'
-        self._id = uuid4().hex
+        self._id = hexlify(urandom(16)).decode()
         self._env = ENV
         self._children = OrderedDict()
         self._parent = None
@@ -158,7 +160,7 @@ class Element(object):
         close_file : bool, default True
             Whether the file has to be closed after write.
         """
-        if isinstance(outfile, str) or isinstance(outfile, bytes):
+        if isinstance(outfile, (str, bytes, Path)):
             fid = open(outfile, 'wb')
         else:
             fid = outfile
@@ -320,43 +322,26 @@ class Figure(Element):
         return self._template.render(this=self, kwargs=kwargs)
 
     def _repr_html_(self, **kwargs):
-        """Displays the Figure in a Jupyter notebook.
-
-        Percent-encoded HTML is stored in data-html attribute, which is used to populate
-        the iframe. This approach does not encounter the 2MB limit in Chrome for storing
-        the HTML in the src attribute with a data URI. The alternative of using a srcdoc
-        attribute is not supported in Microsoft Internet Explorer and Edge.
-
-        """
-        html = urllib.parse.quote(self.render(**kwargs))
-        onload = (
-            'this.contentDocument.open();'
-            'this.contentDocument.write('
-            '    decodeURIComponent(this.getAttribute(\'data-html\'))'
-            ');'
-            'this.contentDocument.close();'
-        )
-
+        """Displays the Figure in a Jupyter notebook."""
+        html = escape(self.render(**kwargs))
         if self.height is None:
             iframe = (
                 '<div style="width:{width};">'
                 '<div style="position:relative;width:100%;height:0;padding-bottom:{ratio};">'  # noqa
                 '<span style="color:#565656">Make this Notebook Trusted to load map: File -> Trust Notebook</span>'  # noqa
-                '<iframe src="about:blank" style="position:absolute;width:100%;height:100%;left:0;top:0;'  # noqa
+                '<iframe srcdoc="{html}" style="position:absolute;width:100%;height:100%;left:0;top:0;'  # noqa
                 'border:none !important;" '
-                'data-html={html} onload="{onload}" '
                 'allowfullscreen webkitallowfullscreen mozallowfullscreen>'
                 '</iframe>'
                 '</div></div>'
-            ).format(html=html, onload=onload, width=self.width, ratio=self.ratio)
+            ).format(html=html, width=self.width, ratio=self.ratio)
         else:
             iframe = (
-                '<iframe src="about:blank" width="{width}" height="{height}"'
+                '<iframe srcdoc="{html}" width="{width}" height="{height}"'
                 'style="border:none !important;" '
-                'data-html={html} onload="{onload}" '
                 '"allowfullscreen" "webkitallowfullscreen" "mozallowfullscreen">'
                 '</iframe>'
-            ).format(html=html, onload=onload, width=self.width, height=self.height)
+            ).format(html=html, width=self.width, height=self.height)
         return iframe
 
     def add_subplot(self, x, y, n, margin=0.05):
@@ -408,10 +393,10 @@ class Html(Element):
         (suitable for embedding html-ready code)
     width : int or str, default '100%'
         The width of the output div element.
-        Ex: 120 , '120px', '80%'
+        Ex: 120 , '80%'
     height : int or str, default '100%'
         The height of the output div element.
-        Ex: 120 , '120px', '80%'
+        Ex: 120 , '80%'
     """
     _template = Template(
         '<div id="{{this.get_name()}}" '
